==> XoopsHP1.1.zip: XoopsHP1.1/module/XoopsHP/language/japanese/main.php <==
<?php
//  ------------------------------------------------------------------------ //
//             --  XoopsHP Module --       Xoops e-Learning System           //
//                     Copyright (c) 2005 SUDOW-SOKEN                        //
//                      <http://www.mailpark.co.jp/>                         //
//  ------------------------------------------------------------------------ //
//               Based on XoopsHP1.01 by Yoshi, aka HowardGee.               //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
define("_AM_SECCONF","ꡡ");
define("_MD_THEFOLLOWING","Υ󶡤Ƥϰʲ̤Ǥ");
define("_MD_RETURN2INDEX","ȥå");
define("_MD_RETURN2QUIZ","");
define("_MD_RESULTLIST","̰");
define("_MD_RESULT_SIMPLE","ʰɽ");
define("_MD_RESULT_DETAIL","ܺɽ");
define("_MD_NEXTPAGE","");
define("_MD_PREVPAGE","");
define("_MD_CURACTIVESEC","ǽʥ");
// kazuo sudow
// define("_MD_CLICK2EDIT","åԽ");
define("_MD_CLICK2EDIT","ʥåԽ");
define("_MD_ADDARTICLE","ɲ");
define("_MD_TITLEC","ȥ롧");
define("_MD_CONTENTC","ե롧");
define("_MD_DOADDARTICLE","ɲ");
// kazuo sudow
// define("_MD_LAST20ART","򥳡Ȥ˰");
define("_MD_LAST20ART","ɽʥ̡");
define("_MD_EDIT","Խ");
define("_MD_EDITARTICLE","Խ");
define("_MD_EDITARTID","ԽID");
define("_MD_FILE2REPLACE","Ƥ֤ե롧");
define("_MD_GO","Go!");
define("_MD_ADDNEWSEC","ɲ");
// kazuo sudow
// define("_MD_SECNAMEC","");
define("_MD_SECNAMEC","̾ν");
define("_MD_MAXCHAR","ʺȾ40ʸ");
define("_MD_SECDESC","");
// kazuo sudow
// define("_MD_EXDESC","ʥδñ");
define("_MD_EXDESC","ʥδñ:Ⱦ250ʸ");
define("_MD_SECQNUM","");
define("_MD_SECDNUM","ѡ");
define("_MD_GOADDSECTION","ɲ");
define("_MD_SAVECHANGES","Խ¸");
define("_MD_DELETE","");
define("_MD_READONLY","<font color='red'>ԽԲ</font>");
define("_MD_EDITTHISSEC","Խ̾%s"); // %s is a section name
define("_MD_THISSECHAS","Υˤ꤬%sѰդƤޤ");
define("_MD_RUSUREDELSEC","ΥƤǤ");
define("_MD_THISDELETESALL","ΥΤ٤Ƥޤ");
define("_MD_YES","Ϥ");
define("_MD_NO","");
define("_MD_ALL","٤");
define("_MD_DELETETHISART","ꡧ%s"); // %sˤ̾
define("_MD_RUSUREDELART","ȤΤ٤ƤΥƤǤ");
define("_MD_RUSUREDELREC","ΥƤǤ");
define("_MD_DBUPDATED","ǡ١");
define("_MD_ERRORSECNAME", "̾ꤷƤ");
define("_MD_ERRORARTNAME", "̾ꤷƤ");
define("_MD_ERRORARTCONT", "ƤꤵƤޤ");
define("_MD_DBNOTUPDATED","ɲü<br/>򤷤ޤץܥǤȤβ̤ꡢƤ");
define("_MD_ERRORQUIZFILE","ɲü<br/>եƤ꤬ޤCGIץ򥪥ˤƽϤľƤߤƤ");
define("_MD_ALERTGUEST","󤷤Ƥޤ󡣥ȥ桼ΥϵϿ᡼⤵ޤ");

define("_MD_LT_ID", "ID");
define("_MD_LT_TITLE", "ȥ롧̾ν");
// kazuo sudow append
define("_MD_LT_TITLE2", "ȥ");
define("_MD_LT_COURSE", "");
define("_MD_LT_OWNER", "");
define("_MD_LT_POSTED", "");
define("_MD_LT_ACTION", "");
define("_MD_LT_DISPLAY", "ɽ");
define("_MD_LT_EXPIRE", "");
define("_MD_LT_RESULTS", "");
define("_MD_LT_DETAILS", "ܺ");
define("_MD_LT_SCORE", "(%)");

// kazuo sudow 1.04
// define("_MD_LT_STUDENT", "");
// define("_MD_LT_STUDENT", "");
define("_MD_LT_STUDENT", "");
define("_MD_LT_GUEST", "");

define("_MD_LT_DATE", "λ");
define("_MD_LT_MYMAX", "ʺǹ");
define("_MD_LT_SITEMAX", "κǹ");
define("_MD_LT_SITEAVG", "ʿ");
define("_MD_LT_LOW", "");
define("_MD_LT_AVRG", "ʿ");
define("_MD_LT_PORTFOLIO", "ؽ");


// kazuo sudow 1.04
// define("_XD_FB_USERNAME","̾");
// define("_XD_FB_USERNAME","");
define("_XD_FB_USERNAME","");

// kazuo sudow
// define("_XD_FB_ID","ϻ̾");
define("_XD_FB_ID","ID");

// kazuo sudow
// define("_XD_FB_UNAME","ȤǤID");
define("_XD_FB_UNAME","̾");

define("_XD_FB_QTITLE","̾");
define("_XD_FB_SCORE","");
// define("_XD_FB_START","");
define("_XD_FB_START","");
// define("_XD_FB_END","λ");
define("_XD_FB_END","λ");
define("_XD_FB_FINISHED_BY","λԿ");
define("_XD_FB_TIMESTAMP","λ");
define("_XD_FB_HOST","ۥ̾");
define("_XD_FB_IP","IPɥ쥹");
define("_XD_FB_CMT","");

// kazuo sudow
// define("_XD_FB_OK","̤ϤʤȽԤξإ᡼ޤ");
define("_XD_FB_OK","ʤӤ᡼ޤ");

define("_XD_FB_GUEST","<font color='red'>ȲԤη̤ϵϿ⤵ޤ</font>");
define("_XD_FB_NG","<font color='red'>顼餫θǷ̤ޤǤ٤äƤߤƤ</font>");
define("_XD_FB_CLSBTN","Ĥ");

define("_AM_MSG_ACCESS_ERROR","¤ޤ");
define("_AM_MSG_UPDATE_FAILED","åץǡȤ˼Ԥޤ");
define("_AM_MSG_UPDATE_SUCCEEDED","åץǡȤޤ");

//*****************************//
//*      ʲԽػ       *//
//*****************************//
// Name of credit site link
define("_MD_CREDITSITE","http://sourceforge.jp/projects/xoopshp/");

//*****************************//
//*      ʲԽػ       *//
//*****************************//
define("_XD_FB_CODE4RESULTS_MARKER", "CODE FOR HANDLING SENDING OF RESULTS");
define("_XD_FB_CODE4RESULTS_INSERT", "//-->");
define("_XD_FB_CODE4RESULTS","
//CODE FOR HANDLING SENDING OF RESULTS

var UserName = '';
var StartTime = (new Date()).toLocaleString();

var ResultForm = '<html><body><form name=\"Results\" action=\"http://www.u-gakugei.ac.jp/~awaji/formmail.cgi\" method=\"post\" enctype=\"x-www-form-encoded\">';
ResultForm += '<input type=\"hidden\" name=\"recipient\" value=\"awaji@jh.setagaya.u-gakugei.ac.jp\"></input>';
ResultForm += '<input type=\"hidden\" name=\"subject\" value=\"test without cgi\"></input>';
ResultForm += '<input type=\"hidden\" name=\"Exercise\" value=\"test without cgi\"></input>';
ResultForm += '<input type=\"hidden\" name=\"realname\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"Score\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"Start_Time\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"End_Time\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"title\" value=\"Thanks!\"></input>';
ResultForm += '<input type=\"hidden\" name=\"bgcolor\" value=\"#ffffff\"></input>';
ResultForm += '<input type=\"hidden\" name=\"text_color\" value=\"#000033\"></input>';
ResultForm += '<input type=\"hidden\" name=\"sort\" value=\"order:realname,Exercise,Score,Start_Time,End_Time\"></input>';
ResultForm += '</form></body></html>';

function GetUserName(){
	UserName = prompt('Please enter your ID:','');
	UserName += '';
	if ((UserName.substring(0,4) == 'null')||(UserName.length < 1)){
		UserName = prompt('Please enter your ID:','');
		UserName += '';
		if ((UserName.substring(0,4) == 'null')||(UserName.length < 1)){
			history.back();
		}
	}
}

function SendResults(Score){
	var today = new Date;
	var NewName = '' + today.getTime();
	var NewWin = window.open('', NewName, 'toolbar=no,location=no,directories=no,status=no, menubar=no,scrollbars=yes,resizable=no,,width=400,height=300');

//If user has prevented popups, no way to proceed -- exit
	if (NewWin == null){
		return;
	}

	NewWin.document.clear();
	NewWin.document.open();
	NewWin.document.write(ResultForm);
	NewWin.document.close();
	NewWin.document.Results.Score.value = Score + '%';
	NewWin.document.Results.realname.value = UserName;
	NewWin.document.Results.End_Time.value = (new Date()).toLocaleString();
	NewWin.document.Results.Start_Time.value = StartTime;
	NewWin.document.Results.submit();
}
");

// StrVars for insertion of GetUserName function
define("_XD_FB_CODE4STARTUP_INSERT", "function StartUp\(\)\{");
define("_XD_FB_CODE4STARTUP","\x09GetUserName();");

// StrVars for incertion of Timeout function
define("_XD_FB_CODE4SEND_INSERT", "\x09if \(\(All(Correct|Done) \=\= true\)\|\|\((Finished|TimeOver) \=\= true\)\)\{|\x09\x09TimeOver \= true;(\r\n|\r|\n)\x09\x09Locked \= true;(\r\n|\r|\n)\x09\x09(\r\n|\r|\n)");define("_XD_FB_CODE4SEND","\x09\x09setTimeout('SendResults(' + Score + ')', 50);");

?>

==> XoopsHP1.11.zip: XoopsHP1.11/module/XoopsHP/language/japanese/main.php <==
<?php
//  ------------------------------------------------------------------------ //
//             --  XoopsHP Module --       Xoops e-Learning System           //
//                     Copyright (c) 2005 SUDOW-SOKEN                        //
//                      <http://www.mailpark.co.jp/>                         //
//  ------------------------------------------------------------------------ //
//               Based on XoopsHP1.01 by Yoshi, aka HowardGee.               //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
define("_AM_SECCONF","ꡡ");
define("_MD_THEFOLLOWING","Υ󶡤Ƥϰʲ̤Ǥ");
define("_MD_RETURN2INDEX","ȥå");
define("_MD_RETURN2QUIZ","");
define("_MD_RESULTLIST","̰");
define("_MD_RESULT_SIMPLE","ʰɽ");
define("_MD_RESULT_DETAIL","ܺɽ");
define("_MD_NEXTPAGE","");
define("_MD_PREVPAGE","");
define("_MD_CURACTIVESEC","ǽʥ");
// kazuo sudow
// define("_MD_CLICK2EDIT","åԽ");
define("_MD_CLICK2EDIT","ʥåԽ");
define("_MD_ADDARTICLE","ɲ");
define("_MD_TITLEC","ȥ롧");
define("_MD_CONTENTC","ե롧");
define("_MD_FILE_MAX","¡ʥХȡˡ");
define("_MD_DOADDARTICLE","ɲ");
// kazuo sudow
// define("_MD_LAST20ART","򥳡Ȥ˰");
define("_MD_LAST20ART","ɽʥ̡");
define("_MD_EDIT","Խ");
define("_MD_EDITARTICLE","Խ");
define("_MD_EDITARTID","ԽID");
define("_MD_FILE2REPLACE","Ƥ֤ե롧");
define("_MD_GO","Go!");
define("_MD_ADDNEWSEC","ɲ");
// kazuo sudow
// define("_MD_SECNAMEC","");
define("_MD_SECNAMEC","̾ν");
define("_MD_MAXCHAR","ʺȾ40ʸ");
define("_MD_SECDESC","");
// kazuo sudow
// define("_MD_EXDESC","ʥδñ");
define("_MD_EXDESC","ʥδñ:Ⱦ250ʸ");
define("_MD_SECQNUM","");
define("_MD_SECDNUM","ѡ");
define("_MD_GOADDSECTION","ɲ");
define("_MD_SAVECHANGES","Խ¸");
define("_MD_DELETE","");
define("_MD_READONLY","<font color='red'>ԽԲ</font>");
define("_MD_EDITTHISSEC","Խ̾%s"); // %s is a section name
define("_MD_THISSECHAS","Υˤ꤬%sѰդƤޤ");
define("_MD_RUSUREDELSEC","ΥƤǤ");
define("_MD_THISDELETESALL","ΥΤ٤Ƥޤ");
define("_MD_YES","Ϥ");
define("_MD_NO","");
define("_MD_ALL","٤");
define("_MD_DELETETHISART","ꡧ%s"); // %sˤ̾
define("_MD_RUSUREDELART","ȤΤ٤ƤΥƤǤ");
define("_MD_RUSUREDELREC","ΥƤǤ");
define("_MD_DBUPDATED","ǡ١");
define("_MD_ERRORSECNAME", "̾ꤷƤ");
define("_MD_ERRORARTNAME", "̾ꤷƤ");
define("_MD_ERRORARTCONT", "ƤꤵƤޤ");
define("_MD_DBNOTUPDATED","ɲü<br/>򤷤ޤץܥǤȤβ̤ꡢƤ");
define("_MD_ERRORQUIZFILE","ɲü<br/>եƤ꤬ޤCGIץ򥪥ˤƽϤľƤߤƤ");
define("_MD_ALERTGUEST","󤷤Ƥޤ󡣥ȥ桼ΥϵϿ᡼⤵ޤ");

define("_MD_LT_ID", "ID");
define("_MD_LT_TITLE", "ȥ롧̾ν");
// kazuo sudow append
define("_MD_LT_TITLE2", "ȥ");
define("_MD_LT_COURSE", "");
define("_MD_LT_OWNER", "");
define("_MD_LT_POSTED", "");
define("_MD_LT_ACTION", "");
define("_MD_LT_DISPLAY", "ɽ");
define("_MD_LT_DISPLAY_ON", "");
define("_MD_LT_DISPLAY_OFF", "");
define("_MD_LT_HIDDEN", "ɽ");
define("_MD_LT_EXPIRE", "");
define("_MD_LT_RESULTS", "");
define("_MD_LT_DETAILS", "ܺ");
define("_MD_LT_SCORE", "(%)");

// kazuo sudow 1.04
// define("_MD_LT_STUDENT", "");
// define("_MD_LT_STUDENT", "");
define("_MD_LT_STUDENT", "");
define("_MD_LT_GUEST", "");

define("_MD_LT_DATE", "λ");
define("_MD_LT_MYMAX", "ʺǹ");
define("_MD_LT_SITEMAX", "κǹ");
define("_MD_LT_SITEAVG", "ʿ");
define("_MD_LT_LOW", "");
define("_MD_LT_AVRG", "ʿ");
define("_MD_LT_PORTFOLIO", "ؽ");


// kazuo sudow 1.04
// define("_XD_FB_USERNAME","̾");
// define("_XD_FB_USERNAME","");
define("_XD_FB_USERNAME","");

// kazuo sudow
// define("_XD_FB_ID","ϻ̾");
define("_XD_FB_ID","ID");

// kazuo sudow
// define("_XD_FB_UNAME","ȤǤID");
define("_XD_FB_UNAME","̾");

define("_XD_FB_QTITLE","̾");
define("_XD_FB_SCORE","");
// define("_XD_FB_START","");
define("_XD_FB_START","");
// define("_XD_FB_END","λ");
define("_XD_FB_END","λ");
define("_XD_FB_FINISHED_BY","λԿ");
define("_XD_FB_TIMESTAMP","λ");
define("_XD_FB_HOST","ۥ̾");
define("_XD_FB_IP","IPɥ쥹");
define("_XD_FB_CMT","");

// kazuo sudow
// define("_XD_FB_OK","̤ϤʤȽԤξإ᡼ޤ");
define("_XD_FB_OK","ʤӤ᡼ޤ");

define("_XD_FB_GUEST","<font color='red'>ȲԤη̤ϵϿ⤵ޤ</font>");
define("_XD_FB_NG","<font color='red'>顼餫θǷ̤ޤǤ٤äƤߤƤ</font>");
define("_XD_FB_CLSBTN","Ĥ");

define("_AM_MSG_ACCESS_ERROR","¤ޤ");
define("_AM_MSG_UPDATE_FAILED","åץǡȤ˼Ԥޤ");
define("_AM_MSG_UPDATE_SUCCEEDED","åץǡȤޤ");

//*****************************//
//*      ʲԽػ       *//
//*****************************//
// Name of credit site link
define("_MD_CREDITSITE","http://sourceforge.jp/projects/xoopshp/");

//*****************************//
//*      ʲԽػ       *//
//*****************************//
define("_XD_FB_CODE4RESULTS_MARKER", "CODE FOR HANDLING SENDING OF RESULTS");
define("_XD_FB_CODE4RESULTS_INSERT", "//-->");
define("_XD_FB_CODE4RESULTS","
//CODE FOR HANDLING SENDING OF RESULTS

var UserName = '';
var StartTime = (new Date()).toLocaleString();

var ResultForm = '<html><body><form name=\"Results\" action=\"http://www.u-gakugei.ac.jp/~awaji/formmail.cgi\" method=\"post\" enctype=\"x-www-form-encoded\">';
ResultForm += '<input type=\"hidden\" name=\"recipient\" value=\"awaji@jh.setagaya.u-gakugei.ac.jp\"></input>';
ResultForm += '<input type=\"hidden\" name=\"subject\" value=\"test without cgi\"></input>';
ResultForm += '<input type=\"hidden\" name=\"Exercise\" value=\"test without cgi\"></input>';
ResultForm += '<input type=\"hidden\" name=\"realname\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"Score\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"Start_Time\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"End_Time\" value=\"\"></input>';
ResultForm += '<input type=\"hidden\" name=\"title\" value=\"Thanks!\"></input>';
ResultForm += '<input type=\"hidden\" name=\"bgcolor\" value=\"#ffffff\"></input>';
ResultForm += '<input type=\"hidden\" name=\"text_color\" value=\"#000033\"></input>';
ResultForm += '<input type=\"hidden\" name=\"sort\" value=\"order:realname,Exercise,Score,Start_Time,End_Time\"></input>';
ResultForm += '</form></body></html>';

function GetUserName(){
	UserName = prompt('Please enter your ID:','');
	UserName += '';
	if ((UserName.substring(0,4) == 'null')||(UserName.length < 1)){
		UserName = prompt('Please enter your ID:','');
		UserName += '';
		if ((UserName.substring(0,4) == 'null')||(UserName.length < 1)){
			history.back();
		}
	}
}

function SendResults(Score){
	var today = new Date;
	var NewName = '' + today.getTime();
	var NewWin = window.open('', NewName, 'toolbar=no,location=no,directories=no,status=no, menubar=no,scrollbars=yes,resizable=no,,width=400,height=300');

//If user has prevented popups, no way to proceed -- exit
	if (NewWin == null){
		return;
	}

	NewWin.document.clear();
	NewWin.document.open();
	NewWin.document.write(ResultForm);
	NewWin.document.close();
	NewWin.document.Results.Score.value = Score + '%';
	NewWin.document.Results.realname.value = UserName;
	NewWin.document.Results.End_Time.value = (new Date()).toLocaleString();
	NewWin.document.Results.Start_Time.value = StartTime;
	NewWin.document.Results.submit();
}
");

// StrVars for insertion of GetUserName function
define("_XD_FB_CODE4STARTUP_INSERT", "function StartUp\(\)\{");
define("_XD_FB_CODE4STARTUP","\x09GetUserName();");

// StrVars for incertion of Timeout function
define("_XD_FB_CODE4SEND_INSERT", "\x09if \(\(All(Correct|Done) \=\= true\)\|\|\((Finished|TimeOver) \=\= true\)\)\{|\x09\x09TimeOver \= true;(\r\n|\r|\n)\x09\x09Locked \= true;(\r\n|\r|\n)\x09\x09(\r\n|\r|\n)");define("_XD_FB_CODE4SEND","\x09\x09setTimeout('SendResults(' + Score + ')', 50);");

?>
